ForgeVersionInfo class

Inheritance
  • Object
  • VersionInfo
  • ForgeVersionInfo
Annotations
  • @JsonSerializable.new()

Constructors

ForgeVersionInfo({required String id, String? inheritsFrom, String? type, String? mainClass, String? minecraftArguments, Arguments? arguments, AssetIndex? assetIndex, String? assets, int? complianceLevel, Downloads? downloads, JavaVersion? javaVersion, List<Library>? libraries, Logging? logging, int? minimumLauncherVersion, String? releaseTime, String? time, List<String>? comments, List<ForgeLibrary>? forgeLibraries})
ForgeVersionInfo.fromJson(Map<String, dynamic> json)
factory

Properties

arguments → Arguments?
finalinherited
assetIndex → AssetIndex?
finalinherited
assets String?
finalinherited
comments List<String>?
final
complianceLevel int?
finalinherited
downloads → Downloads?
finalinherited
forgeLibraries List<ForgeLibrary>?
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
inheritsFrom String?
finalinherited
javaVersion → JavaVersion?
finalinherited
libraries List<Library>?
finalinherited
logging → Logging?
finalinherited
mainClass String?
finalinherited
minecraftArguments String?
finalinherited
minimumLauncherVersion int?
finalinherited
releaseTime String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String?
finalinherited
type String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited