ModuleIdentity class

Class representing the identification information of a Java module. This class is used to accurately detect library duplicates.

Constructors

ModuleIdentity({required String groupId, required String artifactId, required String version, required String path})
Creates a new ModuleIdentity.

Properties

artifactId String
final
groupId String
final
hashCode int
The hash code for this object.
no setterinherited
libraryKey String
Returns the full library key (groupId:artifactId).
no setter
moduleKey String
Generates a module-specific key for duplicate detection.
no setter
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

isNewerThan(ModuleIdentity other) bool
Compares this module's version with another module's version.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compareVersions(String v1, String v2) bool
Compares two semantic versions.
fromLibraryName(String libraryName, String pathToJar) ModuleIdentity?
Creates a ModuleIdentity from a library name.