PathUtils class

Windows上でパス長の制限を回避するためのユーティリティクラス

Constructors

PathUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

ensureSafePath(String filePath) String
指定されたパスが長すぎる場合、Windows上で長いパスサポートを追加します filePath 処理するファイルパス return 長いパスをサポートするために修正されたパス、または元のパス
fileExists(String filePath) Future<bool>
ファイルパスが存在するか確認します。長いパスの場合はプレフィックスを追加します。 filePath 確認するファイルパス return 存在する場合はtrue、存在しない場合はfalse
processSafeClasspath(List<String> classpath, String workingDir) Future<List<String>>
クラスパスを安全な形式に処理します。 長すぎるエントリはシンボリックリンクで置き換えるか、短縮します。
readFileAsString(String filePath) Future<String>
ファイルを読み込みます。長いパスの場合はプレフィックスを追加します。 filePath 読み込むファイルパス return ファイルの内容
writeFileAsString(String filePath, String content) Future<void>
ファイルに書き込みます。長いパスの場合はプレフィックスを追加します。 filePath 書き込むファイルパス content 書き込む内容