JavaHelper class
Helper class for Java-related operations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
extractJar(
String jarPath, String extractDir) → Future< bool> - Extracts a JAR file to the specified directory
-
extractModuleName(
String jarPath) → Future< String?> - Extracts the module name from a JAR file
-
extractModuleVersion(
String jarPath) → Future< String?> - Extracts the version information from a JAR file